## framepack

enter the user menu by (if no py command; use python/python3 instead)
```
py -m framepack
```

### packpack (aka framepack) - inside the code pack

for 1st time launch or model install: run `online.py` (internet access needed)
```
py online.py
```

when all the model files stored locally; then opt to switch to run it entirely offline by:
```
py offline.py
```

### protable pack - extra tools inside the full pack
- cuda128 installer for 50 serise card
- installer.bat (online) and run.bat (offline); linked to the py script above

### reference: [lllyasviel](https://github.com/lllyasviel/FramePack)
